@@ -7,15 +7,15 @@ nltm <- function(formula1=formula(data), formula2=formula(data),
                             "GFM","PHPO"),
                  model=FALSE, x=FALSE, y=FALSE, verbose=FALSE, ...)
 {
-  if(sys.parent()==0)
-    cat(gettextf("Authors: G. Garibotti, A. Tsodikov\n"))
+  ## if(sys.parent()==0)
+  ##   message(gettextf("Authors: G. Garibotti, A. Tsodikov"))
   if(!nlt.model %in% eval(formals()[["nlt.model"]]))
     stop(gettextf("nlt.model should be one of %s",
                   paste(dQuote(eval(formals()[["nlt.model"]])),collapse=", ")),
          domain=NA)
 
   call <- match.call()
-  m <- match.call(expand=FALSE)
+  m <- match.call(expand.dots=FALSE)
   # this is necessary because otherwise eval(m, parent.frame()) doesn't work
   names(m)[names(m)=="formula1"] <- "formula"  
   temp <- c("","formula","data","subset","na.action")
@@ -44,11 +44,11 @@ nltm <- function(formula1=formula(data), formula2=formula(data),
   
   if(!missing(formula2)){
     if(npred==1){
-      cat(gettextf("\nWarning message:\n"))
-      cat(gettextf(paste("Model", nlt.model, sep=" ")))
-      cat(gettextf(" has only one predictor however there are two formulas,\nformula2 will not be used.\n\n"))
+      message(gettextf("\nWarning message:"))
+      message(gettextf(paste("Model", nlt.model, sep=" ")), appendLF=FALSE)
+      message(gettextf(" has only one predictor however there are two formulas,\nformula2 will not be used.\n"))
     }else{
-      m <- match.call(expand=FALSE)
+      m <- match.call(expand.dots=FALSE)
       names(m)[names(m)=="formula2"] <- "formula"  
       temp <- c("","formula","data","subset","na.action")
       m <- m[match(temp, names(m), nomatch=0)]
@@ -83,12 +83,7 @@ nltm <- function(formula1=formula(data), formula2=formula(data),
   controls <- nltm.control(...)
   if(!missing(control)) controls[names(control)] <- control
   
-  if(verbose!=FALSE){
-    res <- .C("openDebug", verbose)
-    verbose <- TRUE
-  }
   fit <- nltm.fit(X1, X2, Y, nlt.model, init, controls, verbose)
-  if(verbose==TRUE) res <- .C("closeDebug")
 
   if(npred==1){
     fit$formula <- formula(Terms1)
